=============
Release Notes
=============

pkgdev 0.2.3 (2022-10-14)
-------------------------

- mask: fix unrelated addition of trailing whitespace (Arthur Zamarin, #98)

- commit: add ``--distdir`` for manifest operations (Arthur Zamarin, #99)

- manifest: better handling of path target (Arthur Zamarin, #85)

pkgdev 0.2.2 (2022-09-20)
-------------------------

- config: fix loading with ``XDG_CONFIG_HOME`` is defined (Arthur Zamarin, #73)

- enable Python 3.11 (Sam James, #81)

- mask: improve parsing of empty header line (Arthur Zamarin, #87)

- mask: improve parsing of empty header line (Arthur Zamarin, #87)

- config: add support for per repo configuration (Arthur Zamarin, #92)

- fix issues with tests for masking with VISUAL set (Arthur Zamarin, #93)

pkgdev 0.2.1 (2022-05-21)
-------------------------

- pkgdev commit: **BREAKING-CHANGE** disable sign-off by default (Arthur
  Zamarin, #68)

- pkgdev: add configuration support. For more info look at [#]_.  (Arthur
  Zamarin, #48, #62)

- pkgdev commit: new summary for stabilizing ALLARCHES (Arthur Zamarin, #61)

- pkgdev mask: offer to send last-rite message email to gentoo-dev ML when
  last-riting a package (Arthur Zamarin, #63)

- pkgdev manifest: add ``--if-modified`` - restrict manifest targets to those
  having uncommitted modifications (Arthur Zamarin, #66)

- pkgdev manifest: add ``--ignore-fetch-restricted`` - skip fetch restricted
  ebuilds (Arthur Zamarin, #67)

.. [#] https://pkgcore.github.io/pkgdev/man/pkgdev.html#config-file-support

pkgdev 0.2.0 (2022-04-10)
-------------------------

- pkgdev commit: Mangle copyright header from single year into year range when
  appropriate (thanks to Thomas Bracht Laumann Jespersen, #49)

- pkgdev commit: Always sort KEYWORDS via mangler (Arthur Zamarin, #47)

- pkgdev commit: For new packages, include version in commit message ("new
  package, add ${PV}") (Arthur Zamarin, #53)

- pkgdev mask: Extend mask comment template (thanks to Thomas Bracht Laumann
  Jespersen, #56)

- pkgdev mask: Accept -b/--bug for referencing bugs (thanks to Thomas Bracht
  Laumann Jespersen, #56)

pkgdev 0.1.9 (2021-07-31)
-------------------------

- pkgdev commit: Revert copyright mangling to previous behavior.

pkgdev 0.1.8 (2021-07-28)
-------------------------

- pkgdev commit: Replace entire copyright date range for new files.

- pkgdev commit: Fix summary generation for certain rename conditions.

pkgdev 0.1.7 (2021-06-29)
-------------------------

- pkgdev commit: Add all matching pkg versions to historical repo (#40).

- pkgdev commit: Use ``git diff-index`` instead of ``git diff`` to avoid config
  settings affecting output.

pkgdev 0.1.6 (2021-06-11)
-------------------------

- pkgdev showkw: Add bash completion support (#38).

- pkgdev commit: Generate summaries for package changes with profile updates,
  e.g. renaming a package and updating profiles/updates in the same commit.

- pkgdev commit: Avoid crash when footer content exists with no summary
  template (#39).

- pkgdev commit: Add initial support for generating summaries from bash diffs.
  For example, this allows automatic summaries to be generated for simple
  PYTHON_COMPAT changes.

pkgdev 0.1.5 (2021-06-03)
-------------------------

- Fix historical repo creation for eclass sourcing.

- Add initial bash completion support.

pkgdev 0.1.4 (2021-05-25)
-------------------------

- pkgdev show: Analog to eshowkw from gentoolkit migrated from pkgcore's
  pshowkw.

- pkgdev manifest: Add -d/--distdir option for custom DISTDIR.

- pkgdev mask: Change removal format to a 'tag: value' style.

pkgdev 0.1.3 (2021-03-26)
-------------------------

- pkgdev mask: Initial implementation of package.mask mangling support.

- pkgdev commit: Allow -s/--scan to accept an optional boolean arg for
  consistency.

- pkgdev commit: Support partial package manifesting (#33).

- pkgdev commit: Add -T/--tag option to add generic commit tags.

pkgdev 0.1.2 (2021-03-19)
-------------------------

- pkgdev commit: Support pulling historical data from unconfigured repos.

- Add initial zsh completion support (#16).

pkgdev 0.1.1 (2021-03-12)
-------------------------

- Replace --ignore-failures option with -A/--ask for ``pkgdev commit`` and
  ``pkgdev push``.

- pkgdev push: Drop explicitly enabled --signed option for gentoo repo (#27).

- pkgdev commit: Add support for -b/--bug and -c/--closes options.

- pkgdev commit: Initial support for summary generation for metadata.xml
  changes (#9).

- pkgdev commit: Enabled signed commits and signoffs based on repo metadata
  (#25).

- pkgdev commit: Initial support for generating modify summaries.

- pkgdev commit: Support summary generation for single rename changes that
  don't involve revbumps.

- pkgdev commit: Add -M/--message-template support.

- pkgdev commit: Support multiple -m/--message options similar to ``git
  commit``.

- pkgdev commit: Support generating manifest summaries (#12).

pkgdev 0.1 (2021-03-05)
-----------------------

- Initial release.

- pkgdev commit: Add subcommand wrapping ``git commit`` supporting commit
  message templating, ebuild manifesting, structured file mangling, and commit
  scanning via pkgcheck.

- pkgdev push: Add subcommand wrapping ``git push`` that verifies local commits
  with pkgcheck before pushing them upstream.

- pkgdev manifest: Add subcommand for manifesting ebuilds.
